#pragma once

/* build batch file */
/*
#ifdef APE_BATCH_FILE_VERSION
Set _MA=881
Set _MAV=8.81
#endif
*/

/* major version number */
#define MAC_VERSION_MAJOR 8

/* build version number */
#define MAC_VERSION_REVISION 81

/* leave this so the end of file doesn't get truncated */
